# Jailbreak status checker

This is a very simple checker that uses the [iOS Jailbreak](https://www.reddit.com/r/jailbreak/) subreddit to see if the *Latest jailbreaks* sidebar content has changed to show that there is a jailbreak for iOS 9.2 or greater.
